@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.4.") or
-    raise "ruby lib version (3.4.8) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("4.0.") or
+    raise "ruby lib version (4.0.1) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby3.4/3.4.0/x86_64-darwin17")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby4.0/4.0.0/x86_64-darwin17")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "8"
-  CONFIG["PATCHLEVEL"] = "72"
+  CONFIG["MAJOR"] = "4"
+  CONFIG["MINOR"] = "0"
+  CONFIG["TEENY"] = "1"
+  CONFIG["PATCHLEVEL"] = "0"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)3.4"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)3.4"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)4.0"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)4.0"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_API_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.4.pc"
+  CONFIG["ruby_pc"] = "ruby-4.0.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -41,11 +41,11 @@ module RbConfig
   CONFIG["rubyarchhdrdir"] = "$(rubyhdrdir)/$(arch)"
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
-  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-3.4.8"
+  CONFIG["rubyhdrdir"] = "$(DESTDIR)/opt/local/include/ruby-4.0.1"
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--disable-rjit' '--without-gmp' '--enable-mkmf-verbose' '--with-opt-dir=/opt/local' '--program-suffix=3.4' '--with-rubyhdrdir=/opt/local/include/ruby-3.4.8' '--with-rubylibprefix=/opt/local/lib/ruby3.4' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--disable-yjit' '--disable-zjit' '--without-gmp' '--without-jemalloc' '--enable-mkmf-verbose' '--with-opt-dir=/opt/local' '--program-suffix=4.0' '--with-rubyhdrdir=/opt/local/include/ruby-4.0.1' '--with-rubylibprefix=/opt/local/lib/ruby4.0' '--with-openssl-dir=/opt/local/libexec/openssl3' '--without-baseruby' '--with-arch=x86_64' 'AR=/opt/local/bin/ar' 'RANLIB=/opt/local/bin/ranlib' 'CC=/usr/bin/clang' 'CXX=/usr/bin/clang++' 'CFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl3/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl3/include -isystem/opt/local/include' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl3/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.4.0"
+  CONFIG["ruby_version"] = "4.0.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin17"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -105,11 +105,19 @@ module RbConfig
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
-  CONFIG["RJIT_SUPPORT"] = "no"
+  CONFIG["JIT_CARGO_SUPPORT"] = "no"
+  CONFIG["RLIB_DIR"] = ""
+  CONFIG["RUST_LIB"] = ""
+  CONFIG["JIT_OBJ"] = ""
+  CONFIG["ZJIT_OBJ"] = ""
+  CONFIG["ZJIT_LIBS"] = ""
+  CONFIG["ZJIT_SUPPORT"] = "no"
   CONFIG["YJIT_OBJ"] = ""
   CONFIG["YJIT_LIBS"] = ""
-  CONFIG["CARGO_BUILD_ARGS"] = ""
   CONFIG["YJIT_SUPPORT"] = "no"
+  CONFIG["CARGO_BUILD_ARGS"] = ""
+  CONFIG["JIT_RUST_FLAGS"] = "--crate-type=staticlib --cfg feature=\\\\\\\"stats_allocator\\\\\\\""
+  CONFIG["ZJIT_TEST_FEATURES"] = ""
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
@@ -121,7 +129,7 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby3.4"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby4.0"
   CONFIG["setup"] = "Setup"
   CONFIG["SOEXT"] = "dylib"
   CONFIG["TRY_LINK"] = ""
@@ -249,7 +257,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&3.4&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&4.0&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -259,8 +267,8 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "15.0.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "15.0"
+  CONFIG["UNICODE_VERSION"] = "17.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "17.0"
   CONFIG["SDKROOT"] = ""
   CONFIG["platform"] = "$(arch)"
   CONFIG["archdir"] = "$(rubyarchdir)"
@@ -365,4 +373,5 @@ module RbConfig
     )
   end
 end
+# Non-nil if configured for cross compiling.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
